@@ -351,7 +351,7 @@ void IncidenceAttachment::editSelectedAttachments()
             QPointer<AttachmentEditDialog> dialog(
                 new AttachmentEditDialog(attitem, mAttachmentView, false));
             dialog->setModal(false);
-            connect(dialog.data(), SIGNAL(hidden()), dialog.data(), SLOT(delayedDestruct()));
+            dialog->setAttribute(Qt::WA_DeleteOnClose, true);
             dialog->show();
         }
     }
@@ -536,6 +536,7 @@ void IncidenceAttachment::setupAttachmentIconView()
     connect(mAttachmentView, &AttachmentIconView::customContextMenuRequested, this, &IncidenceAttachment::showContextMenu);
 
     QGridLayout *layout = new QGridLayout(mUi->mAttachmentViewPlaceHolder);
+    layout->setMargin(0);
     layout->addWidget(mAttachmentView);
 }
 
